window.Gleam.initSearch([{"doc":"gleez","title":"gleez","content":"&lt;h3 align=&quot;center&quot;&gt;\n  &lt;img src=&quot;https://raw.githubusercontent.com/MAHcodes/gleez/master/app/public/imgs/Gleez.svg&quot; width=&quot;700&quot; alt=&quot;Gleez Logo&quot;/&gt;\n  &lt;br/&gt;&lt;br/&gt;\n  Elegant, Modern, and Customizable TailwindCSS components for ✨ &lt;a href=&quot;https://github.com/lustre-labs/lustre&quot;&gt;Lustre&lt;/a&gt; ✨\n&lt;/h3&gt;\n\n&lt;p align=&quot;center&quot;&gt;\n  &lt;a href=&quot;https://github.com/MAHcodes/gleez/blob/master/app/LICENSE&quot;&gt;&lt;img src=&quot;https://img.shields.io/static/v1.svg?style=for-the-badge&amp;label=License&amp;message=MIT&amp;logoColor=d9e0ee&amp;colorA=363a4f&amp;colorB=b7bdf8&quot;/&gt;&lt;/a&gt;\n\t&lt;a href=&quot;https://github.com/MAHcodes/gleez/stargazers&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/stars/MAHcodes/gleez?colorA=363a4f&amp;colorB=b7bdf8&amp;style=for-the-badge&quot;&gt;&lt;/a&gt;\n\t&lt;a href=&quot;https://github.com/MAHcodes/gleez/issues&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/issues/MAHcodes/gleez?colorA=363a4f&amp;colorB=f5a97f&amp;style=for-the-badge&quot;&gt;&lt;/a&gt;\n\t&lt;a href=&quot;https://github.com/MAHcodes/gleez/contributors&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/contributors/MAHcodes/gleez?colorA=363a4f&amp;colorB=a6da95&amp;style=for-the-badge&quot;&gt;&lt;/a&gt;\n&lt;/p&gt;\n\n## :sparkles: Introduction\n\nSimilar to [shadcn](https://ui.shadcn.com/docs)\n\n&gt; This is NOT a component library. It&#39;s a collection of re-usable components that you can copy and paste into your apps.\n\nThis website showcases a real-world application built with Lustre and Gleez. you can check the source code on GitHub, as it&#39;s open source under the MIT License.\n\n## :rocket: Installation\n\nAs mentioned earlier, this is **NOT** a component library. Instead, it&#39;s a collection of reusable components that you can integrate into your apps.\n\nYou can either copy and paste the components directly, or install them using `gleez` cli.\n\nTo install the gleez cli:\n\n```sh\ngleam add gleez\n```\n\n## :rainbow: Colors\n\nGleez `Colors` are basically [TailwindCSS Custom Colors](https://tailwindcss.com/docs/customizing-colors#using-custom-colors)\n\nGleez requires 7 custom TailwindCSS colors:\n\n- `Neutral`\n- `Primary`\n- `Secondary`\n- `Success`\n- `Info`\n- `Warning`\n- `Danger`\n\nEach component variant requires a `Color` type, which is defined within the component itself:\n\n```gleam\npub type Colors {\n  Neutral\n  Primary\n  Secondary\n  Success\n  Info\n  Warning\n  Danger\n}\n```\n\nYou can extend the colors for each component and import them from the component.\n\nTo manually configure the colors:\n\n```js\n// tailwind.config.js\nmodule.exports = {\n  theme: {\n    extend: {\n      colors: {\n        neutral: {\n          DEFAULT: &quot;hsl(var(--neutral) / &lt;alpha-value&gt;)&quot;,\n          foreground: &quot;hsl(var(--neutral-foreground) / &lt;alpha-value&gt;)&quot;,\n        },\n        primary: {\n          DEFAULT: &quot;hsl(var(--primary) / &lt;alpha-value&gt;)&quot;,\n          foreground: &quot;hsl(var(--primary-foreground) / &lt;alpha-value&gt;)&quot;,\n        },\n        secondary: {\n          DEFAULT: &quot;hsl(var(--secondary) / &lt;alpha-value&gt;)&quot;,\n          foreground: &quot;hsl(var(--secondary-foreground) / &lt;alpha-value&gt;)&quot;,\n        },\n        info: {\n          DEFAULT: &quot;hsl(var(--info) / &lt;alpha-value&gt;)&quot;,\n          foreground: &quot;hsl(var(--info-foreground) / &lt;alpha-value&gt;)&quot;,\n        },\n        success: {\n          DEFAULT: &quot;hsl(var(--success) / &lt;alpha-value&gt;)&quot;,\n          foreground: &quot;hsl(var(--success-foreground) / &lt;alpha-value&gt;)&quot;,\n        },\n        warning: {\n          DEFAULT: &quot;hsl(var(--warning) / &lt;alpha-value&gt;)&quot;,\n          foreground: &quot;hsl(var(--warning-foreground) / &lt;alpha-value&gt;)&quot;,\n        },\n        danger: {\n          DEFAULT: &quot;hsl(var(--danger) / &lt;alpha-value&gt;)&quot;,\n          foreground: &quot;hsl(var(--danger-foreground) / &lt;alpha-value&gt;)&quot;,\n        },\n      },\n    },\n  },\n};\n```\n\nDefine CSS variables for light and dark theme:\n\n```css\n/* global.css */\n@layer base {\n  :root,\n  .light {\n    --neutral: 240 10% 40%;\n    --neutral-foreground: 220 23% 95%;\n\n    --primary: 331 82% 64%;\n    --primary-foreground: 220 23% 95%;\n\n    --secondary: 30 81% 63%;\n    --secondary-foreground: 220 23% 95%;\n\n    --success: 109 58% 40%;\n    --success-foreground: 220 23% 95%;\n\n    --info: 220 91% 54%;\n    --info-foreground: 220 23% 95%;\n\n    --warning: 35 77% 49%;\n    --warning-foreground: 220 23% 95%;\n\n    --danger: 347 87% 44%;\n    --danger-foreground: 220 23% 95%;\n  }\n\n  .dark {\n    --neutral: 240 10% 60%;\n    --neutral-foreground: 240 21% 15%;\n\n    --primary: 331 82% 64%;\n    --primary-foreground: 240 21% 15%;\n\n    --secondary: 30 81% 63%;\n    --secondary-foreground: 240 21% 15%;\n\n    --success: 115 54% 76%;\n    --success-foreground: 240 21% 15%;\n\n    --info: 217 92% 76%;\n    --info-foreground: 240 21% 15%;\n\n    --warning: 41 86% 83%;\n    --warning-foreground: 240 21% 15%;\n\n    --danger: 343 81% 75%;\n    --danger-foreground: 240 21% 15%;\n  }\n}\n```\n\n## :question: FAQ\n\n&lt;details&gt;\n    &lt;summary&gt;What is the origin of the name &quot;Gleez&quot;?&lt;/summary&gt;\n    &lt;strong&gt;Gleez&lt;/strong&gt; is a mashup of&lt;strong&gt; Gleam &lt;/strong&gt; and&lt;strong&gt; Deez&lt;/strong&gt;, which raises the question,&lt;strong&gt; &quot;What is Deez?&quot;&lt;/strong&gt;\n&lt;/details&gt;\n\n## :pray: Acknowledgments\n\n- [lustre-ui](https://github.com/lustre-labs/ui) (reference)\n- [gleam-tour](https://github.com/gleam-lang/language-tour) (code highlights)\n- [shadcn](https://github.com/shadcn-ui/ui) (concept)\n- [NextUI](https://github.com/nextui-org/nextui) (inspiration)\n- [Catppuccin](https://github.com/catppuccin/catppuccin) (colors)\n","url":"index.html"},{"doc":"gleez","title":"FetchError","content":"pub opaque type FetchError\n\n\nSynonyms:\ngleez.FetchError\ngleez FetchError","url":"gleez.html#FetchError"},{"doc":"gleez","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\ngleez.main\ngleez main","url":"gleez.html#main"},{"doc":"gleez","title":"gleez","content":"","url":"gleez.html"}]);